package com.upay.sdk.declaration;

import com.alibaba.fastjson15.JSONObject;
import com.upay.sdk.declaration.v_3.builder.BillingOrderBuilder;
import com.upay.sdk.declaration.v_3.executer.BillingOrderExecuter;
import com.upay.sdk.exception.HmacVerifyException;
import com.upay.sdk.exception.RequestException;
import com.upay.sdk.exception.ResponseException;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.ResultListenerAdpater;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;

/**
 * ClassName:BillingOrderServlet <br/>
 * Function: sdk 计费配置servlet <br/>
 * Reason:  TODO ADD REASON. <br/>
 * Date:     2019-06-11 16:41 <br/>
 *
 * @author tianxu
 * @see
 * @since JDK 1.8
 */
public class BillingOrderServlet extends HttpServlet {

    static final Logger LOGGER = LoggerFactory.getLogger(BillingOrderServlet.class);

    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        doPost(req, resp);
    }

    @Override
    protected void doPost(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {

        final String agent = req.getHeader("User-agent");//判断客户端
        LOGGER.info("agent:"+agent);

        //商户Id
        String merchantId = req.getParameter("merchantId");
        //商户请求号
        String requestId = req.getParameter("requestId");
        //二级商户编号
        String subMerchantId = req.getParameter("subMerchantId");
        //收费模式
        String billingMode = req.getParameter("billingMode");
        //收费方式（按笔，按百分比）
        String feeType = req.getParameter("feeType");
        //收费值
        String feeValue = req.getParameter("feeValue");
        //最小收费值
        String minFeeAmount = req.getParameter("minFeeAmount");
        //最大收费值
        String maxFeeAmount = req.getParameter("maxFeeAmount");

        BillingOrderBuilder builder = new BillingOrderBuilder(merchantId);

        builder.setRequestId(requestId)
                .setSubMerchantId(subMerchantId)
                .setBillingMode(billingMode)
                .setFeeType(feeType)
                .setFeeValue(feeValue)
                .setMinFeeAmount(minFeeAmount)
                .setMaxFeeAmount(maxFeeAmount);

        final PrintWriter out = resp.getWriter();

        BillingOrderExecuter executer = new BillingOrderExecuter();

        try{

            executer.bothOrder(builder, new ResultListenerAdpater() {
                @Override
                public void success(JSONObject jsonObject) {
                    LOGGER.debug("success jsonObject:[" + jsonObject + "]");
                    req.getSession().setAttribute("json",jsonObject.toJSONString());
                    out.println("提交成功</br>");
                    out.println(jsonObject);
                }

                @Override
                public void redirect(JSONObject jsonObject, String redirectUrl) throws IOException {
                    resp.sendRedirect(redirectUrl);
                    LOGGER.debug("redirectUrl:[" + redirectUrl + "]");
                }
            });
        }
        catch(ResponseException e){
            out.println("响应异常</br>");
            out.println(e.toString());
        }
        catch(HmacVerifyException e){
            out.println("签名验证异常</br>");
            out.println(e.toString());
        }
        catch(RequestException e){
            out.println("请求异常</br>");
            out.println(e.toString());
        }
        catch(UnknownException e){
            out.println("未知异常</br>");
            out.println(e.toString());
        }
    }
}
