package com.upay.sdk.declaration;

import com.alibaba.fastjson15.JSONObject;
import com.upay.sdk.declaration.v_3.builder.SettlementOrderBuilder;
import com.upay.sdk.declaration.v_3.executer.SettlementOrderExecuter;
import com.upay.sdk.exception.HmacVerifyException;
import com.upay.sdk.exception.RequestException;
import com.upay.sdk.exception.ResponseException;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.ResultListenerAdpater;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;

/**
 * ClassName:SettlementOrderServlet <br/>
 * Function: TODO ADD FUNCTION. <br/>
 * Reason:  TODO ADD REASON. <br/>
 * Date:     2019-06-04 21:19 <br/>
 *
 * @author tianxu
 * @see
 * @since JDK 1.8
 */
public class SettlementOrderServlet extends HttpServlet {

    static final Logger LOGGER = LoggerFactory.getLogger(SettlementOrderServlet.class);

    @Override
    protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
        doPost(req, resp);
    }

    @Override
    protected void doPost(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {

        final String agent = req.getHeader("User-agent");//判断客户端
        LOGGER.info("agent:"+agent);

        //商户Id
        String merchantId = req.getParameter("merchantId");
        //商户请求号
        String requestId = req.getParameter("requestId");
        //二级商户编号
        String subMerchantId = req.getParameter("subMerchantId");
        //结算模式
        String settleMode = req.getParameter("settleMode");
        //周期类型
        String cycleType = req.getParameter("cycleType");
        //周期数据
        String cycleData = req.getParameter("cycleData");
        //最小结算金额
        String minAmount = req.getParameter("minAmount");
        //收款人银行账户号
        String recBankAccountNo = req.getParameter("recBankAccountNo");
        //收款人姓名
        String recName = req.getParameter("recName");
        //收款人身份证号码
        String recIdCardNum = req.getParameter("recIdCardNum");
        LOGGER.info("recIdCardNum============================:"+req.getParameter("recIdCardNum")+":======================");
        //收款人银行代码
        String recBankCode = req.getParameter("recBankCode");
        //开户银行分行名称
        String recBranchBankName = req.getParameter("recBranchBankName");
        //收款人行省编码
        String recProvinceCode = req.getParameter("recProvinceCode");
        //收款人行市编码
        String recCityCode = req.getParameter("recCityCode");
        //收款人账户类型:对公、对私
        String recAccountType = req.getParameter("recAccountType");
        //银行预留手机号
        String recBankPhoneNum = req.getParameter("recBankPhoneNum");

        SettlementOrderBuilder builder = new SettlementOrderBuilder(merchantId);

        builder.setRequestId(requestId)
                .setSubMerchantId(subMerchantId)
                .setSettleMode(settleMode)
                .setCycleType(cycleType)
                .setCycleData(cycleData)
                .setMinAmount(minAmount)
                .setRecBankAccountNo(recBankAccountNo)
                .setRecName(recName)
                .setRecIdCardNum(recIdCardNum)
                .setRecBankCode(recBankCode)
                .setRecBranchBankName(recBranchBankName)
                .setRecProvinceCode(recProvinceCode)
                .setRecCityCode(recCityCode)
                .setRecAccountType(recAccountType)
                .setRecBankPhoneNum(recBankPhoneNum);

        final PrintWriter out = resp.getWriter();
        SettlementOrderExecuter executer = new SettlementOrderExecuter();

        try{

            executer.bothOrder(builder, new ResultListenerAdpater() {
                @Override
                public void success(JSONObject jsonObject) {
                    LOGGER.debug("success jsonObject:[" + jsonObject + "]");
                    req.getSession().setAttribute("json",jsonObject.toJSONString());
                    out.println("提交成功</br>");
                    out.println(jsonObject);
                }

                @Override
                public void redirect(JSONObject jsonObject, String redirectUrl) throws IOException {
                    resp.sendRedirect(redirectUrl);
                    LOGGER.debug("redirectUrl:[" + redirectUrl + "]");
                }
            });

        }
        catch(ResponseException e){
            out.println("响应异常</br>");
            out.println(e.toString());
        }
        catch(HmacVerifyException e){
            out.println("签名验证异常</br>");
            out.println(e.toString());
        }
        catch(RequestException e){
            out.println("请求异常</br>");
            out.println(e.toString());
        }
        catch(UnknownException e){
            out.println("未知异常</br>");
            out.println(e.toString());
        }
    }
}
