/*
 * Project Name:upay-sdk-web
 * File Name:SubMerchantDeclareServlet.java
 * Package Name:com.upay.sdk.declaration.v_3.SubMerchantDeclareServlet
 * Date:2019-05-22 13:25:22
 * Copyright (c) 2019, upay All Rights Reserved.
 */

package com.upay.sdk.declaration;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson15.JSONArray;
import com.upay.sdk.declaration.v_3.subMerchant.builder.SubMerchantDeclareBuilder;
import com.upay.sdk.declaration.v_3.subMerchant.executer.SubMerchantDeclareExecuter;
import com.upay.sdk.entity.SubMerchantCertificate;
import com.upay.sdk.entity.SubMerchantRiskDoc;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.alibaba.fastjson15.JSONObject;
import com.upay.sdk.exception.HmacVerifyException;
import com.upay.sdk.exception.RequestException;
import com.upay.sdk.exception.ResponseException;
import com.upay.sdk.exception.UnknownException;
import com.upay.sdk.executer.ResultListenerAdpater;

/**
 * @ClassName: SubMerchantDeclareServlet
 * @author junyu.qu
 * @date 2019年5月22日13:25:42
 */
public class SubMerchantDeclareServlet extends HttpServlet {
	private static final long serialVersionUID = 2497496473547201491L;
	static final Logger LOGGER = LoggerFactory.getLogger(SubMerchantDeclareServlet.class);

	@Override
	protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
		doPost(req, resp);
	}

	@Override
	protected void doPost(final HttpServletRequest req,final HttpServletResponse resp) throws ServletException, IOException {
		String merchantId = req.getParameter("merchantId");
		String requestId = req.getParameter("requestId");
		String operationType = req.getParameter("operationType");
		String subMerchantId = req.getParameter("subMerchantId");
		String signedName = req.getParameter("signedName");
		String email = req.getParameter("email");
		String phone = req.getParameter("phone");
		String businessScope = req.getParameter("businessScope");
		String authUserId = req.getParameter("authUserId");
		String authEnterpriseId = req.getParameter("authEnterpriseId");
		String hasAgreeProtocol = req.getParameter("hasAgreeProtocol");
		String registerRole = req.getParameter("registerRole");
		String businessLicensePath = req.getParameter("businessLicensePath");
		String openAccountPath = req.getParameter("openAccountPath");
		String legalIdCardProsPath = req.getParameter("legalIdCardProsPath");
		String legalIdCardConsPath = req.getParameter("legalIdCardConsPath");
		String otherCerPath = req.getParameter("otherCerPath");
		String settleBankCardPath = req.getParameter("settleBankCardPath");
		String name = req.getParameter("name");
		String idType = req.getParameter("idType");
		String idNo = req.getParameter("idNo");
		String effectiveDateStart = req.getParameter("effectiveDateStart");
		String effectiveDateEnd = req.getParameter("effectiveDateEnd");
		String register_amount = req.getParameter("REGISTER_AMOUNT");
		String staff_size = req.getParameter("STAFF_SIZE");
		String office_space = req.getParameter("OFFICE_SPACE");

		SubMerchantDeclareBuilder builder = new SubMerchantDeclareBuilder(merchantId);
		builder.setRequestId(requestId)
				.setOperationType(operationType)
				.setSubMerchantId(subMerchantId)
				.setSignedName(signedName)
				.setEmail(email)
				.setPhone(phone)
				.setBusinessScope(businessScope)
				.setAuthUserId(authUserId)
				.setAuthEnterpriseId(authEnterpriseId)
				.setHasAgreeProtocol(hasAgreeProtocol);

		SubMerchantCertificate certificate = new SubMerchantCertificate();
		certificate.setRegisterRole(registerRole);
		certificate.setBusinessLicensePath(businessLicensePath);
		certificate.setOpenAccountPath(openAccountPath);
		certificate.setLegalIdCardProsPath(legalIdCardProsPath);
		certificate.setLegalIdCardConsPath(legalIdCardConsPath);
		certificate.setOtherCerPath(otherCerPath);
		certificate.setSettleBankCardPath(settleBankCardPath);
		certificate.setName(name);
		certificate.setIdType(idType);
		certificate.setIdNo(idNo);
		certificate.setEffectiveDateStart(effectiveDateStart);
		certificate.setEffectiveDateEnd(effectiveDateEnd);
		builder.setDeclarationSubMerchantCertificate(certificate);

		SubMerchantRiskDoc registerAmount = new SubMerchantRiskDoc();
		SubMerchantRiskDoc staffSize = new SubMerchantRiskDoc();
		SubMerchantRiskDoc officeSpace = new SubMerchantRiskDoc();
		registerAmount.setDocCode("REGISTER_AMOUNT");
		registerAmount.setAnswer(register_amount);
		staffSize.setDocCode("STAFF_SIZE");
		staffSize.setAnswer(staff_size);
		officeSpace.setDocCode("OFFICE_SPACE");
		officeSpace.setAnswer(office_space);

		builder.addDeclarationSubMerchantRiskDoc(registerAmount);
		builder.addDeclarationSubMerchantRiskDoc(staffSize);
		builder.addDeclarationSubMerchantRiskDoc(officeSpace);
		final PrintWriter out = resp.getWriter();

		SubMerchantDeclareExecuter executer = new SubMerchantDeclareExecuter();

		try {
			executer.bothSubMerchantDeclare(builder, new ResultListenerAdpater() {
				@Override
				public void success(JSONObject jsonObject) {
					out.println("请求成功！<br/>");
					String result = jsonObject.toJSONString();
					out.print(result);
				}

				@Override
				public void failure(JSONObject jsonObject) {
					out.println("处理失败！<br/>");
					String result = jsonObject.toJSONString();
					out.print(result);
				}

				@Override
				public void pending(JSONObject jsonObject) {
					out.println("待处理！<br/>");
					String result = jsonObject.toJSONString();
					out.print(result);
				}

			});
		} catch (ResponseException e) {
			out.println("响应异常</br>");
			out.println(e.toString());
		} catch (HmacVerifyException e) {
			out.println("签名验证异常</br>");
			out.println(e.toString());
		} catch (RequestException e) {
			out.println("请求异常</br>");
			out.println(e.toString());
		} catch (UnknownException e) {
			out.println("未知异常</br>");
			out.println(e.toString());
		}
	}
}
